Conversation API
================

.. currentmodule:: datamaestro_text.data.conversation

Contextual query reformulation
------------------------------

.. autoclass:: ContextualizedRewrittenQuery
    :members:

.. autoxpmconfig:: ContextualizedQueryRewriting

.. autoxpmconfig:: CanardDataset
    :members: iter

.. autoclass:: OrConvQADatasetAnswer
    :members:
.. autoclass:: OrConvQADatasetHistoryEntry
    :members:
.. autoclass:: OrConvQADataset
    :members:

.. autoxpmconfig:: OrConvQADataset
    :members: iter
